pub enum VMStatus<F> {
Finished {
return_data_offset: u32,
return_data_size: u32,
},
InProgress,
Failure {
reason: FailureReason,
call_stack: ErrorCallStack,
},
ForeignCallWait {
function: String,
inputs: Vec<ForeignCallParam<F>>,
},
}Expand description
Represents the current execution status of the Brillig VM.
Variants
Finished
The VM has completed execution successfully. The output of the program is stored in the VM memory and can be accessed via the provided offset and size.
Fields
InProgress
The VM is still in progress and has not yet completed execution. This is used when simulating execution.
Failure
The VM encountered a failure and halted execution.
Fields
reason: FailureReasonThe reason for the failure.
call_stack: ErrorCallStackThe call stack at the time the failure occurred, useful for debugging nested calls.
ForeignCallWait
The VM process is not solvable as a [foreign call][Opcode::ForeignCall] has been reached where the outputs are yet to be resolved.
The caller should interpret the information returned to compute a [ForeignCallResult] and update the Brillig process. The VM can then be restarted to fully solve the previously unresolved foreign call as well as the remaining Brillig opcodes.