Function vector_flattened_length

fn vector_flattened_length(
    value_types: &[HeapValueType],
    length: SemanticLength,
) -> FlattenedLength
Returns the total number of field elements required to represent the elements in the vector in memory.

Panics if the vector contains nested vectors. Such types are not supported and are rejected by the frontend.