pub(crate) struct FuzzingTrace {
trace: Vec<u32>,
branch_to_feature_map: HashMap<(usize, usize), usize>,
}Expand description
Context structure for all information necessary to compute the fuzzing trace
Fields
trace: Vec<u32>Fuzzer tracing memory.
It records each time a key in the branch_to_feature_map was observed.
Its length is equal to that of the branch_to_feature_map.
branch_to_feature_map: HashMap<(usize, usize), usize>Branch to feature map for fuzzing. Maps program counter + feature to index in the trace vector.
Implementations
Sourceimpl FuzzingTrace
impl FuzzingTrace
fn branch_state(cond: bool) -> usize
fn log_range_state(log: usize) -> usize
Sourcefn field_diff_log<F: AcirField>(a: F, b: F) -> u64
fn field_diff_log<F: AcirField>(a: F, b: F) -> u64
Compute the distance of two field elements as the number of bits required to represent their difference, which is the same as its logarithm.
Sourcefn int_diff_log(a: u128, b: u128) -> u32
fn int_diff_log(a: u128, b: u128) -> u32
Compute the distance of two integers as the logarithm of the absolute value of their difference, which is the number of bits required to represent it.
pub(crate) fn new(branch_to_feature_map: HashMap<(usize, usize), usize>) -> Self
fn record_branch(&mut self, pc: usize, destination: usize)
fn record_conditional_mov(&mut self, pc: usize, branch: bool)
fn record_binary_field_op_comparison<F: AcirField>( &mut self, pc: usize, op: &BinaryFieldOp, lhs: MemoryValue<F>, rhs: MemoryValue<F>, result: MemoryValue<F>, )
fn record_binary_int_op_comparison<F: AcirField>( &mut self, pc: usize, op: &BinaryIntOp, lhs: MemoryValue<F>, rhs: MemoryValue<F>, result: MemoryValue<F>, )
pub(crate) fn get_trace(&self) -> Vec<u32>