pub type Branch = (OpcodePosition, NextOpcodePositionOrState);Expand description
A tuple of the current opcode position and the next opcode position or state
pub type Branch = (OpcodePosition, NextOpcodePositionOrState);A tuple of the current opcode position and the next opcode position or state