pub(crate) struct ArrayAddress(MemoryAddress);Expand description
Wrapper for array addresses, with convenience methods for various offsets.
The array consists of a ref-count followed by a number of items according the size indicated by the type.
Tuple Fields
0: MemoryAddressImplementations
Sourceimpl ArrayAddress
impl ArrayAddress
Sourcepub(crate) fn items_start(&self) -> MemoryAddress
pub(crate) fn items_start(&self) -> MemoryAddress
The start of the items, after the meta-data.