pub enum FailureReason {
Trap {
revert_data_offset: u32,
revert_data_size: u32,
},
RuntimeError {
message: String,
},
}Expand description
Represents the reason why the Brillig VM failed during execution.
Variants
Trap
A trap was encountered, which indicates an explicit failure from within the VM program.
A trap is triggered explicitly by the [trap opcode][Opcode::Trap]. The revert data is referenced by the offset and size in the VM memory.
Fields
RuntimeError
A runtime failure during execution. This error is triggered by all opcodes aside the [trap opcode][Opcode::Trap]. For example, a [binary operation][Opcode::BinaryIntOp] can trigger a division by zero error.