pub enum MemoryValue<F> {
Field(F),
U1(bool),
U8(u8),
U16(u16),
U32(u32),
U64(u64),
U128(u128),
}Expand description
A single typed value in the Brillig VM’s memory.
Memory in the VM is strongly typed and can represent either a native field element or an integer of a specific bit width. This enum encapsulates all supported in-memory types and allows conversion between representations.
Variants
Implementations
Sourceimpl<F: Display> MemoryValue<F>
impl<F: Display> MemoryValue<F>
Sourcepub fn new_integer(value: u128, bit_size: IntegerBitSize) -> Self
pub fn new_integer(value: u128, bit_size: IntegerBitSize) -> Self
Builds an integer-typed memory value.
pub fn bit_size(&self) -> BitSize
Sourceimpl<F: AcirField> MemoryValue<F>
impl<F: AcirField> MemoryValue<F>
Sourcepub fn new_from_field(value: F, bit_size: BitSize) -> Self
pub fn new_from_field(value: F, bit_size: BitSize) -> Self
Builds a memory value from a field element, either field or integer type.
If the bit size indicates an integer type, the value is downcast to fit into the specified size.
Sourcepub fn new_checked(value: F, bit_size: BitSize) -> Option<Self>
pub fn new_checked(value: F, bit_size: BitSize) -> Option<Self>
Builds a memory value from a field element, checking that the value is within the bit size,
otherwise returns None.
Sourcepub fn to_field(&self) -> F
pub fn to_field(&self) -> F
Converts the memory value to a field element, independent of its type.
Sourcepub fn to_u128(&self) -> Result<u128, MemoryTypeError>
pub fn to_u128(&self) -> Result<u128, MemoryTypeError>
Converts the memory value to U128, if the value is an integer.
Sourcepub fn expect_field(self) -> Result<F, MemoryTypeError>
pub fn expect_field(self) -> Result<F, MemoryTypeError>
Extracts the field element from the memory value, if it is typed as field element.
pub(crate) fn expect_u1(self) -> Result<bool, MemoryTypeError>
pub(crate) fn expect_u8(self) -> Result<u8, MemoryTypeError>
pub(crate) fn expect_u16(self) -> Result<u16, MemoryTypeError>
pub(crate) fn expect_u32(self) -> Result<u32, MemoryTypeError>
pub(crate) fn expect_u64(self) -> Result<u64, MemoryTypeError>
pub(crate) fn expect_u128(self) -> Result<u128, MemoryTypeError>